

| |docs| |travis| |coveralls| |landscape| |version|
| |downloads| |wheel| |supported-versions| |supported-implementations|

.. |docs| image:: https://readthedocs.org/projects/dpkt/badge/?style=flat
    :target: https://readthedocs.org/projects/dpkt
    :alt: Documentation Status

.. |travis| image:: http://img.shields.io/travis/kbandla/dpkt/master.png?style=flat
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/kbandla/dpkt

.. |coveralls| image:: http://img.shields.io/coveralls/kbandla/dpkt/master.png?style=flat
    :alt: Coverage Status
    :target: https://coveralls.io/r/kbandla/dpkt

.. |landscape| image:: https://landscape.io/github/kbandla/dpkt/master/landscape.svg?style=flat
    :target: https://landscape.io/github/kbandla/dpkt/master
    :alt: Code Quality Status

.. |version| image:: http://img.shields.io/pypi/v/dpkt.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/dpkt

.. |downloads| image:: http://img.shields.io/pypi/dm/dpkt.svg
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/dpkt

.. |wheel| image:: https://img.shields.io/pypi/wheel/dpkt.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/dpkt

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/dpkt.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/dpkt

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/dpkt.svg 
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/dpkt

